RxAction class

Send action

Inheritance
Available extensions
Annotations

Constructors

RxAction()
Send action

Properties

action → RxVoid
Track action listener
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value ↔ RxVoid
The current value stored in this notifier.
getter/setter pairinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
call() → void
Re-call all the registered listeners.
inherited
dispose() → void
Discards any resources used by the object.
inherited
next(Function onAction, {Duration timeLimit = const Duration(seconds: 10)}) → Future<RxVoid>
Wait the next change of a RxNotifier. The timeLimit is 10 seconds by default. onAction callback execute after register listener.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
setValue(RxVoid newValue) → void
Tear-offs for set value in this notifier.
inherited
setValueWithoutReaction(RxVoid newValue) → void
Tear-offs for set value without reaction.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator +(Listenable listenable) → Listenable

Available on Listenable, provided by the ListenableMergeExtension extension

Merge Listenable objects.
operator ==(Object other) → bool
The equality operator.
inherited