RxList<T> class

Inheritance
Mixed-in types
Available extensions

Constructors

RxList([List<T>? list])

Properties

first ↔ T
The first element.
getter/setter pairinherited-setteroverride-getter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setteroverride
isNotEmpty → bool
Whether this collection has at least one element.
no setteroverride
iterator → Iterator<T>
A new Iterator that allows iterating the elements of this Iterable.
no setteroverride
last ↔ T
The last element.
getter/setter pairinherited-setteroverride-getter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length ↔ int
The number of objects in this list.
getter/setter pairoverride
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
reversed → Iterable<T>
An Iterable of the objects in this list in reverse order.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → T
Checks that this iterable has only one element, and returns that element.
no setteroverride
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJS → JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or cloning the List.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
toJSProxyOrRef → JSArray<T>

Available on List<T>, provided by the ListToJSArray extension

Converts this List to a JSArray by either casting, unwrapping, or proxying the List.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(T element) → void
Adds value to the end of this list, extending the length by one.
override
addAll(Iterable<T> iterable) → void
Appends all objects of iterable to the end of this list.
override
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
any(bool test(T element)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asMap() → Map<int, T>
An unmodifiable Map view of this list.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
asRx() → RxList<T>

Available on List<T>, provided by the RxListExtension extension

Convert a List to RxList.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → List<R>
Returns a view of this list as a list of R instances.
inherited
clear() → void
Removes all objects from this list; the length of the list becomes zero.
override
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
dispose() → void
Discards any resources used by the object.
inherited
elementAt(int index) → T
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(T element)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
fillRange(int start, int end, [T? fill]) → void
Overwrites a range of elements with fillValue.
override
firstWhere(bool test(T element), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(T element)) → void
Invokes action on each element of this iterable in iteration order.
override
getRange(int start, int end) → Iterable<T>
Creates an Iterable that iterates over a range of elements.
override
indexOf(Object? element, [int start = 0]) → int
The first index of element in this list.
inherited
indexWhere(bool test(T element), [int start = 0]) → int
The first index in the list that satisfies the provided test.
inherited
insert(int index, T element) → void
Inserts element at position index in this list.
override
insertAll(int index, Iterable<T> iterable) → void
Inserts all objects of iterable at position index in this list.
override
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastIndexOf(Object? element, [int? start]) → int
The last index of element in this list.
inherited
lastIndexWhere(bool test(T element), [int? start]) → int
The last index in the list that satisfies the provided test.
inherited
lastWhere(bool test(T element), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
map<T>(T f(T element)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
reduce(T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(covariant T element) → bool
Removes the first occurrence of value from this list.
override
removeAt(int index) → T
Removes the object at position index from this list.
override
removeLast() → T
Removes and returns the last object in this list.
override
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeRange(int start, int end) → void
Removes a range of elements from the list.
override
removeWhere(bool test(T element)) → void
Removes all objects from this list that satisfy test.
override
replaceRange(int start, int end, Iterable<T> newContents) → void
Replaces a range of elements with the elements of replacements.
override
retainWhere(bool test(T element)) → void
Removes all objects from this list that fail to satisfy test.
inherited
setAll(int index, Iterable<T> iterable) → void
Overwrites elements with the objects of iterable.
override
setRange(int start, int end, Iterable<T> iterable, [int skipCount = 0]) → void
Writes some elements of iterable into a range of this list.
override
shuffle([Random? random]) → void
Shuffles the elements of this list randomly.
override
singleWhere(bool test(T element), {T orElse()?}) → T
The single element that satisfies test.
override
skip(int count) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
override
skipWhile(bool test(T element)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
override
sort([int compare(T, T)?]) → void
Sorts this list according to the order specified by the compare function.
override
sublist(int start, [int? end]) → List<T>
Returns a new list containing the elements between start and end.
override
take(int count) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T element)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<T>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
A string representation of this object.
inherited
where(bool test(T element)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(List<T> other) → List<T>
Returns the concatenation of this list and other.
override
operator +(Listenable listenable) → Listenable

Available on Listenable, provided by the ListenableMergeExtension extension

Merge Listenable objects.
operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → T
The object at the given index in the list.
override
operator []=(int index, T value) → void
Sets the value at the given index in the list to value.
override

Static Methods

of<T>(List<T> list) → RxList<T>