RxSet<T> class

Inheritance
Mixed-in types
Available extensions

Constructors

RxSet([Set<T>? set])

Properties

first → T
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<T>
An iterator that iterates over the elements of this set.
no setteroverride
last → T
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of elements in this Iterable.
no setteroverride
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → T
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(T value) → bool
Adds value to the set.
override
addAll(Iterable<T> elements) → void
Adds all elements to this set.
inherited
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
any(bool test(T value)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
asRx() → RxSet<T>

Available on Set<T>, provided by the RxSetExtension extension

Convert a Set to RxSet.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → Set<R>
Provides a view of this set as a set of R instances.
inherited
clear() → void
Removes all elements from the set.
inherited
contains(Object? element) → bool
Whether value is in the set.
override
containsAll(Iterable<Object?> other) → bool
Whether this set contains all the elements of other.
inherited
difference(Set<Object?> other) → Set<T>
Creates a new set with the elements of this that are not in other.
inherited
dispose() → void
Discards any resources used by the object.
inherited
elementAt(int index) → T
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool f(T value)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> f(T element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(T value), {T orElse()?}) → T
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, T element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<T> other) → Iterable<T>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void f(T element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
intersection(Set<Object?> other) → Set<T>
Creates a new set which is the intersection between this set and other.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(T value), {T orElse()?}) → T
The last element that satisfies the given predicate test.
inherited
lookup(Object? element) → T?
If an object equal to object is in the set, return it.
override
map<T>(T f(T element)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
reduce(T combine(T value, T element)) → T
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) → bool
Removes value from the set.
override
removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
removeWhere(bool test(T value)) → void
Removes all elements of this set that satisfy test.
inherited
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
inherited
retainWhere(bool test(T value)) → void
Removes all elements of this set that fail to satisfy test.
inherited
singleWhere(bool test(T value), {T orElse()?}) → T
The single element that satisfies test.
inherited
skip(int n) → Iterable<T>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(T value)) → Iterable<T>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int n) → Iterable<T>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(T value)) → Iterable<T>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<T>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<T>
Creates a Set with the same elements and behavior as this Set.
override
toString() → String
A string representation of this object.
inherited
union(Set<T> other) → Set<T>
Creates a new set which contains all the elements of this set and other.
inherited
where(bool f(T value)) → Iterable<T>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator +(Listenable listenable) → Listenable

Available on Listenable, provided by the ListenableMergeExtension extension

Merge Listenable objects.
operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

of<T>(Set<T> set) → RxSet<T>